pub struct MockSecretVersionsApi {
SecretVersionsApi_expectations: MockSecretVersionsApi_SecretVersionsApi,
}Fields
SecretVersionsApi_expectations: MockSecretVersionsApi_SecretVersionsApiImplementations
Sourceimpl MockSecretVersionsApi
impl MockSecretVersionsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockSecretVersionsApi
impl MockSecretVersionsApi
Sourcepub fn expect_bulk_delete(&mut self) -> &mut Expectation
pub fn expect_bulk_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_delete method
Sourcepub fn expect_get_by_id(&mut self) -> &mut Expectation
pub fn expect_get_by_id(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_by_id method
Sourcepub fn expect_get_many_by_ids(&mut self) -> &mut Expectation
pub fn expect_get_many_by_ids(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_many_by_ids method
Sourcepub fn expect_get_versions_by_secret_id(&mut self) -> &mut Expectation
pub fn expect_get_versions_by_secret_id(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_versions_by_secret_id method
Sourcepub fn expect_restore_version(&mut self) -> &mut Expectation
pub fn expect_restore_version(&mut self) -> &mut Expectation
Create an Expectation for mocking the restore_version method